class Xorriso < Formula
  desc "ISO9660+RR manipulation tool"
  homepage "https://www.gnu.org/software/xorriso/"
  url "https://ftp.gnu.org/gnu/xorriso/xorriso-1.5.6.tar.gz"
  mirror "https://ftpmirror.gnu.org/xorriso/xorriso-1.5.6.tar.gz"
  sha256 "d4b6b66bd04c49c6b358ee66475d806d6f6d7486e801106a47d331df1f2f8feb"
  license "GPL-2.0-or-later"

  uses_from_macos "zlib"

  # Submit the patch into the upstream, see:
  # https://lists.gnu.org/archive/html/bug-xorriso/2023-06/msg00000.html
  patch :DATA

  def install
    system "./configure", "--disable-debug", "--disable-dependency-tracking",
                          "--prefix=#{prefix}"
    system "make"

    # `make install` has to be deparallelized due to the following error:
    #   mkdir: /usr/local/Cellar/xorriso/1.4.2/bin: File exists
    #   make[1]: *** [install-binPROGRAMS] Error 1
    # Reported 14 Jun 2016: https://lists.gnu.org/archive/html/bug-xorriso/2016-06/msg00003.html
    ENV.deparallelize { system "make", "install" }
  end

  test do
    assert_match "List of xorriso extra features", shell_output("#{bin}/xorriso -list_extras")
    assert_match version.to_s, shell_output("#{bin}/xorriso -version")
  end
end

__END__
diff --git a/libisofs/rockridge.h b/libisofs/rockridge.h
index 5649eb7..01c4224 100644
--- a/libisofs/rockridge.h
+++ b/libisofs/rockridge.h
@@ -41,6 +41,8 @@

 #include "ecma119.h"

+/* For ssize_t */
+#include <unistd.h>

 #define SUSP_SIG(entry, a, b) ((entry->sig[0] == a) && (entry->sig[1] == b))
